@@ -134,6 +134,45 @@ class VoiceAssistantSubscriptionFlag(enum.IntFlag):
     API_AUDIO = 1 << 2
 
 
+@_frozen_dataclass_decorator
+class AreaInfo(APIModelBase):
+    area_id: int = 0
+    name: str = ""
+
+    @classmethod
+    def convert_list(cls, value: list[Any]) -> list[AreaInfo]:
+        ret = []
+        for x in value:
+            if isinstance(x, dict):
+                ret.append(AreaInfo.from_dict(x))
+            else:
+                ret.append(AreaInfo.from_pb(x))
+        return ret
+
+    @classmethod
+    def convert(cls, value: Any) -> AreaInfo:
+        if isinstance(value, dict):
+            return cls.from_dict(value)
+        return cls.from_pb(value)
+
+
+@_frozen_dataclass_decorator
+class SubDeviceInfo(APIModelBase):
+    device_id: int = 0
+    name: str = ""
+    area_id: int = 0
+
+    @classmethod
+    def convert_list(cls, value: list[Any]) -> list[SubDeviceInfo]:
+        ret = []
+        for x in value:
+            if isinstance(x, dict):
+                ret.append(SubDeviceInfo.from_dict(x))
+            else:
+                ret.append(SubDeviceInfo.from_pb(x))
+        return ret
+
+
 @_frozen_dataclass_decorator
 class DeviceInfo(APIModelBase):
     uses_password: bool = False
@@ -154,6 +193,16 @@ class DeviceInfo(APIModelBase):
     bluetooth_proxy_feature_flags: int = 0
     suggested_area: str = ""
     bluetooth_mac_address: str = ""
+    api_encryption_supported: bool = False
+    devices: list[SubDeviceInfo] = converter_field(
+        default_factory=list, converter=SubDeviceInfo.convert_list
+    )
+    areas: list[AreaInfo] = converter_field(
+        default_factory=list, converter=AreaInfo.convert_list
+    )
+    area: AreaInfo = converter_field(
+        default_factory=AreaInfo, converter=AreaInfo.convert
+    )
 
     def bluetooth_proxy_feature_flags_compat(self, api_version: APIVersion) -> int:
         if api_version < APIVersion(1, 9):
@@ -199,11 +248,19 @@ class EntityInfo(APIModelBase):
     entity_category: EntityCategory | None = converter_field(
         default=EntityCategory.NONE, converter=EntityCategory.convert
     )
+    device_id: int = 0
 
 
 @_frozen_dataclass_decorator
 class EntityState(APIModelBase):
     key: int = 0
+    device_id: int = 0
+
+
+@_frozen_dataclass_decorator
+class CommandProtoMessage(APIModelBase):
+    key: int = 0
+    device_id: int = 0
 
 
 # ==================== BINARY SENSOR ====================
@@ -329,7 +386,8 @@ class LightColorCapability(enum.IntFlag):
 class ColorMode(APIIntEnum):
     UNKNOWN = 0
     ON_OFF = 1
-    BRIGHTNESS = 2
+    LEGACY_BRIGHTNESS = 2
+    BRIGHTNESS = 3
     WHITE = 7
     COLOR_TEMPERATURE = 11
     COLD_WARM_WHITE = 19
@@ -1410,6 +1468,7 @@ class VoiceAssistantEventType(APIIntEnum):
     VOICE_ASSISTANT_STT_VAD_END = 12
     VOICE_ASSISTANT_TTS_STREAM_START = 98
     VOICE_ASSISTANT_TTS_STREAM_END = 99
+    VOICE_ASSISTANT_INTENT_PROGRESS = 100
 
 
 class VoiceAssistantTimerEventType(APIIntEnum):
